@@ -88,7 +88,7 @@ impl Context {
     pub fn duration() -> Duration {
         CONTEXT.read().unwrap().duration
     }
-    pub fn base_octave() -> Octave {
+    pub fn octave() -> Octave {
         CONTEXT.read().unwrap().octave
     }
     pub fn fretted() -> FrettedContext {
@@ -100,6 +100,12 @@ impl Context {
     pub fn set_scale(scale: Scale) {
         CONTEXT.write().unwrap().scale = scale;
     }
+    pub fn set_duration(duration: Duration) {
+        CONTEXT.write().unwrap().duration = duration;
+    }
+    pub fn set_octave(octave: Octave) {
+        CONTEXT.write().unwrap().octave = octave;
+    }
 }
 
 impl Context {
@@ -114,18 +120,18 @@ impl Context {
             Duration::from_ident(#ident)
         }
     }
-    pub fn octave(tweak: &Option<OctaveTweakDsl>) -> Octave {
-        let base = Self::base_octave();
+    pub fn tweaked_octave(tweak: &Option<OctaveTweakDsl>) -> Octave {
+        let base = Self::octave();
         tweak.as_ref().map(|t| t.tweak(&base)).unwrap_or(base)
     }
     pub fn octave_quote(tweak: &Option<OctaveTweakDsl>) -> TokenStream {
-        let ident = Self::octave(tweak).to_ident();
+        let ident = Self::tweaked_octave(tweak).to_ident();
         quote! {
             Octave::from_ident(#ident)
         }
     }
     pub fn calc_note(tweak: &Option<OctaveTweakDsl>, syllable: &Syllable) -> Note {
-        let octave = Self::octave(tweak);
+        let octave = Self::tweaked_octave(tweak);
         let key = Self::key();
         let scale = Self::scale();
         scale.calc_note(&key, &SyllableNote::new(octave, *syllable))
@@ -211,7 +217,7 @@ impl ToTokens for ContextDsl {
             }
             Self::Octave(x) => {
                 CONTEXT.write().unwrap().octave = Octave::from_ident(x.to_string().as_str());
-                let comment = format!("{}", Context::base_octave());
+                let comment = format!("{}", Context::octave());
                 quote! {
                     ProtoEntry::from(("dsl::context::octave", #comment))
                 }
@@ -247,7 +253,7 @@ impl ContextDsl {
             }
             Self::Octave(x) => {
                 CONTEXT.write().unwrap().octave = Octave::from_ident(x.to_string().as_str());
-                let comment = format!("{}", Context::base_octave());
+                let comment = format!("{}", Context::octave());
                 ProtoEntry::from(("dsl::context::octave", comment))
             }
             Self::StringNum(x) => {
